@@ -7,7 +7,7 @@ require 'cairo'
 
 class ::Gdk::SubPartsVoter < Gdk::SubParts
 
-  attr_reader :votes, :icon_width, :icon_height, :margin
+  attr_reader :votes
 
   def initialize(*args)
     super
@@ -61,6 +61,18 @@ class ::Gdk::SubPartsVoter < Gdk::SubParts
     }
   end
 
+  def icon_width
+    helper.scale(@icon_width)
+  end
+
+  def icon_height
+    helper.scale(@icon_height)
+  end
+
+  def margin
+    helper.scale(@margin)
+  end
+
   def get_user_by_point(x)
     if(x >= @icon_ofst)
       node = @avatar_rect.each_with_index.to_a.bsearch{|_| _[0].last > x }
@@ -83,27 +95,31 @@ class ::Gdk::SubPartsVoter < Gdk::SubParts
       icon_height end end
 
   def add(new)
-    if UserConfig[:"#{name}_by_anyone_show_timeline"]
-      if not @votes.include?(new)
-        before_height = height
-        @votes << new
-        if(before_height == height)
-          helper.on_modify
-        else
-          helper.reset_height end
-        self end end end
+    if not @votes.include?(new)
+      before_height = height
+      @votes << new
+      if(before_height == height)
+        helper.on_modify
+      else
+        helper.reset_height
+      end
+      self
+    end
+  end
   alias << add
 
   def delete(user)
-    if UserConfig[:"#{name}_by_anyone_show_timeline"]
-      if not @votes.include?(user)
-        before_height = height
-        @votes.delete(user)
-        if(before_height == height)
-          helper.on_modify
-        else
-          helper.reset_height end
-        self end end end
+    if not @votes.include?(user)
+      before_height = height
+      @votes.delete(user)
+      if(before_height == height)
+        helper.on_modify
+      else
+        helper.reset_height
+      end
+      self
+    end
+  end
 
   def name
     raise end
@@ -111,7 +127,7 @@ class ::Gdk::SubPartsVoter < Gdk::SubParts
   # このSubPartsのアイコンのPixbufを返す。
   # title_icon_model メソッドをオーバライドしない場合、こちらを必ずオーバライドしなければならない
   def title_icon
-    title_icon_model.pixbuf(width: @icon_width, height: @icon_height)
+    title_icon_model.pixbuf(width: icon_width, height: icon_height)
   end
 
   # このSubPartsのアイコンをあらわすModelを返す。
@@ -164,10 +180,10 @@ class ::Gdk::SubPartsVoter < Gdk::SubParts
       @user_icon[user[:id]] = pixbuf
       helper.on_modify } end
 
-  def pl_count(context = dummy_context)
+  def pl_count(context = Cairo::Context.dummy)
     layout = context.create_pango_layout
     layout.wrap = Pango::WrapMode::CHAR
-    layout.font_description = Pango::FontDescription.new(UserConfig[:mumble_basic_font])
+    layout.font_description = helper.font_description(UserConfig[:mumble_basic_font])
     layout.text = "#{get_vote_count}"
     layout
   end
