@@ -7,7 +7,7 @@ module Plugin::Mastodon
     extend Gem::Deprecate
     include Diva::Model::MessageMixin
 
-    register :mastodon_status, name: 'トゥート', timeline: true, reply: true, myself: true
+    register :mastodon_status, name: Plugin[:mastodon]._('トゥート'), timeline: true, reply: true, myself: true
 
     field.string :id, required: true
     field.string :original_uri, required: true # APIから取得するfediverse uniqueなURI文字列
@@ -336,9 +336,18 @@ module Plugin::Mastodon
       text
     end
 
-    # register reply:true用API
+    # 自分が _self_ にリプライを返していればtrue
     def mentioned_by_me?
-      !mentions.empty? && from_me?
+      children.any?(&:from_me?)
+    end
+
+    # _self_ を宛先としたStatusのリストを返す
+    def children
+      @children ||= Set.new(retweeted_statuses)
+    end
+
+    protected def add_child(child)
+      children << child
     end
 
     # この投稿の投稿主のアカウントの全権限を所有していればtrueを返す
@@ -459,7 +468,7 @@ module Plugin::Mastodon
     end
 
     private def replyto_source_force
-      if domain.nil?
+      unless domain
         # 何故かreplyviewerに渡されたStatusからdomainが消失することがあるので復元を試みる
         world, = Plugin.filtering(:mastodon_current, nil)
         if world
@@ -477,9 +486,9 @@ module Plugin::Mastodon
           end
         end
       end
-      resp = Plugin::Mastodon::API.status!(domain, in_reply_to_id)
-      return nil if resp.nil?
-      Status.build(domain, [resp.value]).first
+      Plugin::Mastodon::API.status!(domain, in_reply_to_id)
+        &.yield_self { |r| Status.build(domain, r.value).first }
+        &.tap { |parent| parent.add_child(self) }
     end
 
     # 返信表示用
@@ -551,5 +560,8 @@ module Plugin::Mastodon
     end
     deprecate :post, "spell (see: https://reference.mikutter.hachune.net/reference/2017/11/28/spell.html#compose-twitter)", 2018, 11
 
+    def receive_user_idnames
+      mentions.map(&:acct).to_a
+    end
   end
 end
