@@ -7,10 +7,6 @@ Plugin.create :search do
     Plugin.call(:search_start, token.model.query)
   end
 
-  intent :twitter_hashtag do |token|
-    Plugin.call(:search_start, token.model.title)
-  end
-
   Delayer.new do
     refresh_tab
   end
@@ -35,7 +31,7 @@ Plugin.create :search do
     query_box = Plugin::Search::QueryBox.new(self)
     @tag ||= handler_tag do
       tab(:search, _("検索")) do
-        set_icon Skin['search.png']
+        set_icon Skin[:search]
         shrink
         nativewidget query_box
         expand
