@@ -57,7 +57,16 @@ Plugin::create(:basic_settings) do
       :license => (file_get_contents('../LICENSE') rescue nil),
       :website => _('https://mikutter.hachune.net/'),
       :logo => Skin.photo('icon.png'),
-      :authors => ['toshi_a', 'Phenomer', 'osa_k', 'katsyoshi', 'ahiru', 'cobodo'],
+      :authors => %w[
+        @toshi_a@social.mikutter.hachune.net
+        Phenomer
+        @osa_k@social.mikutter.hachune.net
+        katsyoshi
+        @ahiru@social.mikutter.hachune.net
+        @cobodo@mstdn.kanagu.info
+        @shibafu528@social.mikutter.hachune.net
+        @yuntan_t@mstdn.maud.io
+      ],
       :artists => ['toshi_a', 'soramame_bscl', 'seibe2'],
       :documenters => ['toshi_a']
     }
